Further capabilities in the library
===================================

This section shows some of the more intricate capabilities of the library.

Contents:

.. toctree::
   :maxdepth: 2

   strategies.rst
   classification_of_strategies.rst
   strategy_transformers.rst
   tournament_results.rst
   reading_and_writing_interactions.rst
   parallel_processing.rst
   using_the_cache.rst
   setting_a_seed.rst
   player_equality.rst
   games.rst
